@@ -15,7 +15,8 @@
 #'
 run_custom_query <- function(variableList, query, query_name) {
 
-  cli::cli_progress_step("Connecting the database...", spinner = TRUE)
+tryCatch({
+  cli::cli_progress_step("Connecting to the Open Targets Genetics GrpahQL API...", spinner = TRUE)
   otg_cli <- ghql::GraphqlClient$new(url = "https://api.genetics.opentargets.org/graphql")
   otg_qry <- ghql::Query$new()
 
@@ -31,4 +32,12 @@ run_custom_query <- function(variableList, query, query_name) {
   result <- eval(parse(text = query_exec))
 
   return (result)
+}, error = function(e) {
+  # Handling connection timeout
+  if(grepl("Timeout was reached", e$message)) {
+    stop("Connection timeout reached while connecting to the Open Targets Genetics GraphQL API.")
+  } else {
+    stop(e) # Handle other types of errors
+  }
+})
 }
